# BetterStatcord.py ![Code Quality](https://www.codefactor.io/repository/github/iapetus-11/betterstatcord.py/badge) ![PYPI Version](https://img.shields.io/pypi/v/betterstatcord.py.svg?color=0FAE6E) ![PYPI Weekly Downloads](https://img.shields.io/pypi/dw/betterstatcord.py?color=0FAE6E)
A better Statcord API library for Python + Discord.py (and maybe its forks)

## Advantages
- **It's blazin fast**: The official library is full of inefficient, slow, and unnecessary code which does nothing **except slow your bot down**.
- **Cleaner and smaller codebase**: BetterStatcord.py is smaller and cleaner, making it much more reliable and understandable.
- **Easier to use**: For its basic functionality, all you need is **one** line of code to set it up!
- **More accurate**: This library has more accurate statistics than the official one.
- **Supports clustering**: This library has a special class for clustered bots, which supports the clustered API stats endpoint.

## Examples
- Check out the [examples folder](https://github.com/Iapetus-11/betterstatcord.py/tree/main/examples)
